@@ -5,7 +5,7 @@
  * or copyright law is prohibited.
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
- * © 2013 Open-Xchange Inc., Tarrytown, NY, USA. info@open-xchange.com
+ * © 2016 OX Software GmbH, Germany. info@open-xchange.com
  *
  * @author David Bauer <david.bauer@open-xchange.com>
  * @author Julian Bäume <julian.baeume@open-xchange.com>
@@ -14,12 +14,12 @@
 'use strict';
 
 module.exports = function (grunt) {
-    grunt.config.extend('watch', {
+    grunt.config.merge({ watch: {
         help: {
             files: [
                 'help/**/*'
             ],
             tasks: ['default', 'send_livereload']
         },
-    });
+    }});
 };
